@@ -46,13 +46,19 @@ test_that("*m278hlund* errs in calculation", {
 test_that("*m278inshcm* errs in thermal conductivity", {
   data(m278insdata)
   expect_equal(
-    m278inshcm(110, m278insdata[["material"]]),
-    c(0.096000, 0.075250, 0.149500, 0.143250, 0.149500, 0.108000, 0.096000,
-      0.104250, 0.137250, 0.147250, 0.147250, 0.085250,
-      0.133250, 0.157250, 0.080250, 0.060000, 0.064000, 0.059500, 0.059500,
-      0.063000, 0.132500, 0.057250, 0.070000, 0.050000, 0.089875, 0.094875,
-      0.059750, 0.060875, 0.069875, 0.061250, 0.064000, 0.065875, 0.089875,
-      0.091875, 0.083250, 0.050000, 0.069875, 0.071875, 0.074875
+    m278inshcm(
+      temperature = rep(c(110, 0), each = nrow(m278insdata)),
+      material    = rep.int(m278insdata[["material"]], 2)
+    ),
+    c(
+      c(0.096000, 0.075250, 0.149500, 0.143250, 0.149500, 0.108000, 0.096000,
+        0.104250, 0.137250, 0.147250, 0.147250, 0.085250,
+        0.133250, 0.157250, 0.080250, 0.060000, 0.064000, 0.059500, 0.059500,
+        0.063000, 0.132500, 0.057250, 0.070000, 0.050000, 0.089875, 0.094875,
+        0.059750, 0.060875, 0.069875, 0.061250, 0.064000, 0.065875, 0.089875,
+        0.091875, 0.083250, 0.050000, 0.069875, 0.071875, 0.074875
+      )
+      ,m278insdata[["lambda"]]*1e-3 + m278insdata[["k"]]*1e-6*20
     ),
     tolerance = 1e-6
   )
